@@ -6,9 +6,7 @@ Created on Sun Feb 21 08:31:01 2021
 @author: nattawoot
 """
 import os
-import sys
 import json
-from datetime import datetime, date, time
 
 import jsonpickle
 import boto3
@@ -16,58 +14,12 @@ from botocore.client import Config
 from botocore.exceptions import ClientError, ParamValidationError
 from loguru import logger
 
-from wud.helper import logger_wraps, timeit
+from wud.helper import logger_wraps, timeit, EnhancedJSONEncoder,EnhancedJSONDecoder
 
 jsonpickle.set_encoder_options('json', sort_keys=False, indent=4)
 
 #%% AWS S3
             
-class EnhancedJSONEncoder(json.JSONEncoder):
-    def default(self, obj):
-        if isinstance(obj, datetime):
-            ARGS = ('year', 'month', 'day', 'hour', 'minute',
-                     'second', 'microsecond')
-            return {'__type__': 'datetime',
-                    'args': [getattr(obj, a) for a in ARGS]}
-        elif isinstance(obj, date):
-            ARGS = ('year', 'month', 'day')
-            return {'__type__': 'date',
-                    'args': [getattr(obj, a) for a in ARGS]}
-        elif isinstance(obj, time):
-            ARGS = ('hour', 'minute', 'second', 'microsecond')
-            return {'__type__': 'time',
-                    'args': [getattr(obj, a) for a in ARGS]}
-        # elif isinstance(obj, timedelta):
-        #     ARGS = ('days', 'seconds', 'microseconds')
-        #     return {'__type__': 'timedelta',
-        #             'args': [getattr(obj, a) for a in ARGS]}
-        # elif isinstance(obj, decimal.Decimal):
-        #     return {'__type__': 'decimal.Decimal',
-        #             'args': [str(obj),]}
-        elif hasattr(obj, '__class__'):         
-            return obj.__dict__
-        else:
-            return super().default(obj)
-
-
-class EnhancedJSONDecoder(json.JSONDecoder):
-
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, object_hook=self.object_hook,
-                         **kwargs)
-
-    def object_hook(self, d): 
-        if '__type__' not in d:
-            return d
-        o = sys.modules[__name__]
-        for e in d['__type__'].split('.'):
-            o = getattr(o, e)
-        args, kwargs = d.get('args', ()), d.get('kwargs', {})
-        return o(*args, **kwargs)
-
-            
-            
-            
 def get_aws_keys():
     
     # AWS Lambda reserve AWS_ACCESS_KEY_ID, AWS_ACCESS_SECRET_KEY for thier temporary key
